@@ -14,45 +14,46 @@
 
 #include "kgpgeditor.h"
 
-#include <QTextStream>
-#include <QTextCodec>
-#include <QPainter>
-#include <QtDBus/QtDBus>
-#include <QtGui/QPrinter>
-#include <QtGui/QPrintDialog>
-#include <QVBoxLayout>
-#include <QWidget>
-
-#include <KToggleAction>
-#include <KStandardAction>
-#include <KActionCollection>
-#include <KIcon>
-#include <KFindDialog>
-#include <KFind>
-#include <KMenuBar>
-#include <KShortcut>
-#include <KEncodingFileDialog>
-#include <kio/netaccess.h>
-#include <kio/renamedialog.h>
-#include <KMessageBox>
-#include <KTemporaryFile>
-#include <KAction>
-#include <KLocale>
-#include <KDebug>
-#include <KRecentFilesAction>
-#include <KToolBar>
-
+#include "detailedconsole.h"
 #include "selectsecretkey.h"
 #include "kgpgmd5widget.h"
 #include "kgpgsettings.h"
 #include "keyservers.h"
 #include "sourceselect.h"
-#include "kgpgtextedit.h"
 #include "kgpg.h"
-#include "kgpgtextinterface.h"
-#include "kgpgkeyservergettransaction.h"
 #include "keysmanager.h"
+#include "editor/kgpgtextedit.h"
 #include "transactions/kgpgdecrypt.h"
+#include "transactions/kgpgkeyservergettransaction.h"
+#include "transactions/kgpgsigntext.h"
+#include "transactions/kgpgverify.h"
+
+#include <KAction>
+#include <KActionCollection>
+#include <KDebug>
+#include <KEncodingFileDialog>
+#include <KFind>
+#include <KFindDialog>
+#include <KIcon>
+#include <KLocale>
+#include <KMenuBar>
+#include <KMessageBox>
+#include <KRecentFilesAction>
+#include <KShortcut>
+#include <KStandardAction>
+#include <KTemporaryFile>
+#include <KToggleAction>
+#include <KToolBar>
+#include <QPainter>
+#include <QTextCodec>
+#include <QTextStream>
+#include <QVBoxLayout>
+#include <QWidget>
+#include <QtDBus/QtDBus>
+#include <QtGui/QPrintDialog>
+#include <QtGui/QPrinter>
+#include <kio/netaccess.h>
+#include <kio/renamedialog.h>
 
 class KgpgView : public QWidget {
 public:
@@ -629,16 +630,13 @@ void KgpgEditor::slotSignFile(const KUrl &url)
 
         delete opts;
 
-        QStringList Options;
-        if (KGpgSettings::asciiArmor())
-            Options << QLatin1String( "--armor" );
-        if (KGpgSettings::pgpCompatibility())
-            Options << QLatin1String( "--pgp6" );
-        Options << QLatin1String( "--detach-sign" );
+	KGpgSignText::SignOptions sopts = KGpgSignText::DetachedSignature;
+	if (KGpgSettings::asciiArmor())
+		sopts |= KGpgSignText::AsciiArmored;
 
-        KGpgTextInterface *interface = new KGpgTextInterface();
-        connect(interface, SIGNAL(fileSignFinished(KUrl::List&)), SLOT(slotSignFileFin()));
-        interface->signFiles(signKeyID, url, Options);
+	KGpgSignText *signt = new KGpgSignText(this, signKeyID, KUrl::List(url), sopts);
+	connect(signt, SIGNAL(done(int)), SLOT(slotSignFileFin()));
+	signt->start();
     }
 }
 
@@ -672,11 +670,15 @@ void KgpgEditor::slotVerifyFile(const KUrl &url)
             }
         }
 
-        // pipe gpg command
-        KGpgTextInterface *interface = new KGpgTextInterface(this);
-        connect(interface, SIGNAL(verifyquerykey(QString)), SLOT(importSignatureKey(QString)));
-        connect(interface, SIGNAL(verifyfinished()), SLOT(slotVerifyFinished()));
-        interface->KgpgVerifyFile(url, KUrl(sigfile));
+	KUrl::List chkfiles;
+	if (sigfile.isEmpty())
+		chkfiles << url;
+	else
+		chkfiles << KUrl::fromPath(sigfile);
+
+	KGpgVerify *verify = new KGpgVerify(this, chkfiles);
+	connect(verify, SIGNAL(done(int)), m_editor, SLOT(slotVerifyDone(int)));
+	verify->start();
     }
 }
 
@@ -691,8 +693,15 @@ void KgpgEditor::slotCheckMd5()
 	}
 }
 
-void KgpgEditor::importSignatureKey(const QString &id)
+void KgpgEditor::importSignatureKey(const QString &id, const QString &fileName)
 {
+	sender()->deleteLater();
+
+	if (KMessageBox::questionYesNo(0,
+			i18n("<qt><b>Missing signature:</b><br />Key id: %1<br /><br />Do you want to import this key from a keyserver?</qt>", id),
+			fileName, KGuiItem(i18n("Import")), KGuiItem(i18n("Do Not Import"))) != KMessageBox::Yes)
+		return;
+
 	KeyServer *ks = new KeyServer(this);
 
 	connect(ks, SIGNAL(importFinished(QStringList)), SLOT(slotDownloadKeysFinished(QStringList)));
@@ -709,9 +718,19 @@ void KgpgEditor::slotDownloadKeysFinished(QStringList ids)
 }
 
 void
-KgpgEditor::slotVerifyFinished()
+KgpgEditor::slotVerifyFinished(const QString &id, const QString &message)
 {
 	sender()->deleteLater();
+
+	QString showId;
+
+	if (id.isEmpty())
+		showId = i18n("No signature found.");
+	else
+		showId = id;
+
+	(void) new KgpgDetailedInfo(this, showId, message, QStringList(),
+			i18nc("Caption of message box", "Verification Finished"));
 }
 
 void KgpgEditor::slotOptions()
